# PyGame+

## Installation
```
pip install pygameplus
```

## Requirements
- pygame

## Roadmap
### 1.0
- ✔️ GameObject class
    - ✔️ Rendering layers
    - ❌ Component based workflow
- ❌ Input Manager
    - ❌ Drag'n'drop
- ❌ Utils
    - ❌ Timer